#
# spec file for package libqxmpp
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_qt4 1
%define build_qt5 0

Name:           libqxmpp
Version:        0.8.3
Release:        6.4
Summary:        Qt XMPP Library
License:        LGPL-2.0+
Group:          System/Libraries
Url:            http://qxmpp.org
Source0:        https://github.com/qxmpp-project/qxmpp/archive/v%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FEATURE-OPENSUSE to make Qt5 build.
Patch0:         libqxmpp-qt5.patch

BuildRequires:  fdupes
%if %build_qt4
BuildRequires:  pkgconfig(QtCore)
%endif
%if %build_qt5
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Xml)
%endif
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vpx)

%description
QXmpp is a cross-platform C++ XMPP client library. It is based on Qt and C++.

QXmpp is pretty intuitive and easy to use. It uses Qt extensively. Qt is the only
third party library it is dependent on. Users need to a have working knowledge of
C++ and Qt basics (Signals and Slots and Qt data types). The underlying TCP socket
and the XMPP RFCs (RFC3920 and RFC3921) have been encapsulated into classes and
functions. Therefore the user would not be bothered with these details. But it is
always recommended to the advanced users to read and enjoy the low level details.

%package -n %{name}0
Summary:        Qt XMPP Library
Group:          System/Libraries

%description -n %{name}0
QXmpp is a cross-platform C++ XMPP client library. It is based on Qt and C++.

QXmpp is pretty intuitive and easy to use. It uses Qt extensively. Qt is the only
third party library it is dependent on. Users need to a have working knowledge of
C++ and Qt basics (Signals and Slots and Qt data types). The underlying TCP socket
and the XMPP RFCs (RFC3920 and RFC3921) have been encapsulated into classes and
functions. Therefore the user would not be bothered with these details. But it is
always recommended to the advanced users to read and enjoy the low level details.

%package -n %{name}-devel

Summary:        Qxmpp Development Files
Group:          Development/Libraries/C and C++
%if %build_qt4
Requires:       %{name}0 = %{version}
%endif
%if %build_qt5
Requires:       %{name}-0 = %{version}
%endif

%description -n %{name}-devel
It's a development package for qxmpp.

QXmpp is a cross-platform C++ XMPP client library. It is based on Qt and C++.

%package doc
Summary:        Qxmpp library documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This packages provides documentation of Qxmpp library API.

%prep
%setup -q -n qxmpp-%{version}
%if %build_qt5
%patch0 -p1
%endif
# A hack vs. "E: arch-independent-package-contains-binary-or-object"
# after %%check.
cp -r examples doc/

%build
%if %build_qt4
qmake \
%endif
%if %build_qt5
qmake-qt5 \
%endif
      PREFIX=%{_prefix} \
      LIBDIR=%{_lib} \
      QMAKE_STRIP="" \
      QMAKE_CXXFLAGS+="%{optflags}" \
      QXMPP_USE_OPUS=1 \
      QXMPP_USE_SPEEX=1 \
      QXMPP_USE_THEORA=1 \
      QXMPP_USE_VPX=1

make V=1 %{?_smp_mflags}

%install
%makeinstall INSTALL_ROOT=%{buildroot}
%fdupes %{buildroot}%{_datadir}/doc/qxmpp/

%check
make V=1 %{?_smp_mflags} check

%post -n %{name}0 -p /sbin/ldconfig

%postun -n %{name}0 -p /sbin/ldconfig

%files -n %{name}0
%defattr(-,root,root)
%doc AUTHORS CHANGELOG LICENSE.LGPL README*
%{_libdir}/%{name}.so.*

%files -n %{name}-devel
%defattr(-,root,root)
%{_libdir}/%{name}.so
%if %build_qt4
%{_includedir}/qxmpp
%{_libdir}/pkgconfig/qxmpp.pc
%endif
%if %build_qt5
%{_includedir}/qxmpp-qt5
%{_libdir}/pkgconfig/qxmpp-qt5.pc
%endif

%files doc
%defattr(-,root,root)
%doc doc/examples

%changelog
* Sat Mar 14 2015 dap.darkness@gmail.com
- update to 0.8.3
  * Add a QXmppClient::sslErrors signal to report SSL errors.
  * Handle broken servers which send "bad-auth"
    instead of "not-authorized".
  * Fix a compilation issue with Qt 5.5 due to a missing include.
  * Do not install test cases.
  * Remove trailing comma after last item in enums.
* Fri Jan  9 2015 dap.darkness@gmail.com
- update to 0.8.2
  * Refactor HTML documentation so that "make docs" works in
    out-of-source builds.
  * Add support for Opus audio codec.
  * Enable error concealment for VPX video codec.
  * Use QString() instead of "" for default methods arguments,
    to enable building project which use QT_NO_CAST_FROM_ASCII.
  * Add support for legacy SSL.
  * Add XEP-0333: Chat Markers attributes to QXmppMessage.
  * Add QXmppClient::socketErrorString
    to retrieve socket error string.
  * Add equality/inequality operators for QXmppVCardIq.
  * Add "make check" command to run tests.
-packaging
  * Switched to tarball from github.
  * Added libqxmpp-qt5.patch to implement Qt5 alternative.
  * Switched to pkgconfig() at Requires section.
  * Broken old distros: SLE11, openSUSE~11.4.
  * Let make be verbose.
  * Added check section.
* Thu Mar 27 2014 dap.darkness@gmail.com
- update to 0.8.0
  * Add organizations info interface to QXmppVCardIq.
  * Remove deprecated QXmppPresence::Status type.
- Source URL was put back.
- Url tag and Source URL were updated to qxmpp.org.
* Sun Mar  9 2014 dap.darkness@gmail.com
- Source URL was temporary deleted to pass factory-auto.
* Sun Mar  9 2014 dap.darkness@gmail.com
- update to 0.7.6+git.2014.03.09
  * Added QPair include just in case.
  * Avoid keeping the source QDomDocument in QXmppElement.
    Serialize the node instead of keeping QDomElement
    with a ref to the original QDomDOcument.
  * QXmppElement::sourceDomElement().
  * Namespace-based matching for known elements.
  * Cover non-'x' extensions in tests.
  * Support other extensions besides 'x' in QXmppMessage.
  * Fixes to support Qt5.
  * Re-order member initialization (silences GCC warning).
  * Fixed possible memory leak in QXmppTransferManager.
  * Added missing assert for connecting signal in QXmppStream.
  * Fixed C-style pointer cast.
  * Fixed uninitialized pointers in QXmppOutgoingClientPrivate.
  * Fixed uninitialized pointer in QXmppCallPrivate.
  * Fixed uninitialized pointer in QXmppRtpAudioChannelPrivate.
  * Fixed uninitialized member in QXmppOutgoingClient.
  * Fix QXmppServer incoming connections with Qt5 (issue 175).
* Mon Aug 19 2013 dap.darkness@gmail.com
- Full VoIP support was enabled.
- Spec was fixed up via spec-cleaner.
* Fri Mar 22 2013 schwab@suse.de
- Override LIBDIR instead of moving the library manually
* Mon Mar 11 2013 dap.darkness@gmail.com
- update to 0.7.6
  * Add QXmppClient::insertExtension to insert an extension at a given index.
  * Disable Facebook/Google specific mechanisms if no corresponding credentials.
- Mistake at doc-subpackage description was fixed.
* Thu Dec 20 2012 dap.darkness@gmail.com
- update to 0.7.4
  * Add XEP-0249: Direct MUC Invitations attributes to QXmppMessage.
  * Add XEP-0045: Multi-User Chat attributes to QXmppPresence.
  * Improve GuiClient, stop using deprecated APIs.
  * Improve QXmppServer.
  * Improve QXmppTransferManager.
* Tue Sep  4 2012 nekolayer@yandex.ru
- changed to upstream url
  - package renamed
  - Update to version 0.7.1
  - Fix export of QXmppVCardPhone class.
  - New XEPs:
  * XEP-0033: Extended Stanza Addressing
  - Remove deprecated APIs:
  * QXmppRosterManager::rosterChanged()
  * QXmppConfiguration::sASLAuthMechanism()
  - Improve vCard support:
  * Add support for free-form descriptive text.
  * Make it possible to have several addresses.
  * Make it possible to have several e-mail addresses.
  * Make it possible to have several phone numbers.
  - Make it possible to set the client's extended information form (XEP-0128).
  - Make sure QXmppDiscoveryManager only emits results.
  - Fix XEP-0115 verification strings (remove duplicate features, sort form values)
  - Fix issues:
  * Issue 144: QXmppBookmarkConference autojoin parsing
  - Add support for see-other-host server change.
  - Add support for X-MESSENGER-OAUTH2 authentication for Windows Live Messenger.
  - Make it possible to disable non-SASL authentication.
  - Add QXmppClient::isAuthenticated() to query whether authentication has been
    performed.
* Mon Sep  3 2012 idonmez@suse.com
- Fix name for devel package
* Fri Aug 10 2012 dap.darkness@gmail.com
- update to 0.6.3.1
  * Source tree was sync with upstream.
  * The library became dynamic.
* Tue Jul  3 2012 dvaleev@suse.com
- fix ppc64 libdir
* Tue Mar  6 2012 nekolayer@yandex.ru
- update to 0.3.47
* Sun Jul 31 2011 nlminhtl@gmail.com
- first package
